@@ -10,6 +10,7 @@ import matplotlib.pyplot as plt
 
 # Owned Libraries
 from z2n import file
+from z2n import stats
 from z2n.series import Series
 
 
@@ -23,20 +24,19 @@ class Plot(Series):
     > A integer for the current number of plots.
     * `data : Series`
     > A series object that represents the data.
-    * `back : Series`
+    * `noise : Series`
     > A series object that represents the background.
 
     Methods
     -------
     """
 
-    def __init__(self, data, back) -> None:
+    def __init__(self) -> None:
         super().__init__()
         self.plots = 1
-        self.data = data
-        self.back = back
+        self.data = Series()
+        self.noise = Series()
         self.figure, self.axes = plt.subplots()
-        self.axis = plt.gca().get_xlim()
 
     def get_input(self) -> str:
         """Return the input image name."""
@@ -111,7 +111,7 @@ class Plot(Series):
             self.figure, self.axes = plt.subplots(
                 self.plots, sharex=True, sharey=True)
             self.axes[0].plot(self.data.bins, self.data.z2n, color='tab:blue')
-            self.axes[1].plot(self.back.bins, self.back.z2n, color='tab:cyan')
+            self.axes[1].plot(self.noise.bins, self.noise.z2n, color='tab:cyan')
 
     def plot_file(self) -> int:
         """Plot the periodogram from a file."""
@@ -156,11 +156,11 @@ class Plot(Series):
         """Create subplot of the background."""
         flag = 0
         click.secho("The background file is needed.", fg='yellow')
-        if not self.back.set_time():
+        if not self.noise.set_time():
             try:
-                self.back.bins = np.array(self.data.bins)
+                self.noise.bins = np.array(self.data.bins)
                 plt.close()
-                self.back.set_periodogram()
+                self.noise.set_periodogram()
                 self.add_background()
                 self.plot_figure()
             except KeyboardInterrupt:
@@ -177,27 +177,36 @@ class Plot(Series):
         flag = 0
         if self.data.z2n.size:
             if click.confirm("Recalculate on a selected region"):
-                if not self.change_region():
+                if not self.crop_region():
                     if self.plots == 2:
                         if click.confirm("Do you want to keep the background"):
                             try:
-                                self.back.bins = np.array(self.data.bins)
+                                self.noise.bins = np.array(self.data.bins)
                                 plt.close()
-                                self.back.set_periodogram()
+                                self.noise.set_periodogram()
+                                self.plot_figure()
+                                self.data.set_parameters()
+                                self.plot_figure()
+                                self.data.get_parameters()
                             except KeyboardInterrupt:
                                 click.secho(
                                     "Error calculating the periodogram.", fg='red')
                                 flag = 1
                         else:
                             self.rm_background()
-                            del self.back.time
-                            del self.back.bins
-                            del self.back.z2n
+                            del self.noise.time
+                            del self.noise.bins
+                            del self.noise.z2n
+                            self.plot_figure()
+                            self.data.set_parameters()
+                            self.plot_figure()
+                            self.data.get_parameters()
                     else:
                         if click.confirm("Do you want to add a background file"):
                             self.plot_background()
-                        self.change_forest()
+                        self.plot_figure()
                         self.data.set_parameters()
+                        self.plot_figure()
                         self.data.get_parameters()
                 else:
                     flag = 1
@@ -210,8 +219,9 @@ class Plot(Series):
                     try:
                         plt.close()
                         self.data.set_periodogram()
-                        self.change_forest()
+                        self.plot_figure()
                         self.data.set_parameters()
+                        self.plot_figure()
                         self.data.get_parameters()
                         if click.confirm("Do you want to add a background file"):
                             self.plot_background()
@@ -226,7 +236,7 @@ class Plot(Series):
                 flag = 1
         return flag
 
-    def change_region(self) -> int:
+    def crop_region(self) -> int:
         """Change limits on a periodogram region."""
         flag = 0
         click.secho("This will recalculate the periodogram.", fg='yellow')
@@ -292,31 +302,6 @@ class Plot(Series):
                 flag = 1
         return flag
 
-    def change_forest(self) -> None:
-        """Select regions of uncertainty."""
-        click.secho("Select regions to estimate error.", fg='yellow')
-        self.plot_figure()
-        regions = click.prompt("How many regions", type=int)
-        if regions > 0:
-            means = np.zeros(regions)
-            for region in range(regions):
-                opt = True
-                while opt:
-                    if click.confirm(f"Is the the region {region + 1} selected"):
-                        self.axis = plt.gca().get_xlim()
-                        lower = np.where(np.isclose(
-                            self.data.bins, self.axis[0], 0.1))
-                        upper = np.where(np.isclose(
-                            self.data.bins, self.axis[1], 0.1))
-                        low = np.rint(np.median(lower)).astype(int)
-                        up = np.rint(np.median(upper)).astype(int)
-                        means[region] = np.mean(self.data.z2n[low:up])
-                        opt = False
-            self.data.forest = np.mean(means)
-            self.data.set_bandwidth()
-        else:
-            click.secho("No regions to estimate error.", fg='yellow')
-
     def save_image(self) -> None:
         """Save the image to a file."""
         plt.tight_layout()
