@@ -4,10 +4,10 @@
 # Other libraries
 import click
 import numpy as np
-from tqdm import trange
 from numba import jit
-
-desc = click.style('Calculating the periodogram', fg='yellow')
+from tqdm import trange
+from scipy import optimize
+import matplotlib.pyplot as plt
 
 
 @jit(forceobj=True, parallel=True, fastmath=True)
@@ -43,7 +43,8 @@ def sampling(series) -> None:
     -------
     None
     """
-    observation(series)
+    if not series.observation:
+        observation(series)
     series.sampling = (1 / series.observation)
 
 
@@ -228,7 +229,9 @@ def periodogram(series) -> None:
     -------
     None
     """
-    for freq in trange(series.bins.size, desc=desc):
+    for freq in trange(
+            series.bins.size, desc=click.style(
+                'Calculating the periodogram', fg='yellow')):
         for harmonic in range(series.harmonics):
             series.z2n[freq] = series.z2n[freq] + \
                 z2n(series.time, series.bins[freq], harmonic + 1)
@@ -284,7 +287,8 @@ def period(series) -> None:
     -------
     None
     """
-    frequency(series)
+    if not series.frequency:
+        frequency(series)
     series.period = 1 / series.frequency
 
 
@@ -302,32 +306,12 @@ def pfraction(series) -> None:
     -------
     None
     """
-    frequency(series)
+    if not series.potency:
+        potency(series)
     pfrac = (2 * series.potency) / series.time.size
     series.pulsed = pfrac ** 0.5
 
 
-@jit(forceobj=True, parallel=True, fastmath=True)
-def forest(series) -> None:
-    """
-    Calculate the forest potency.
-
-    Parameters
-    ----------
-    series : Series
-        A time series object.
-
-    Returns
-    -------
-    None
-    """
-    potency(series)
-    index = np.argmax(series.z2n)
-    low = np.rint(index - (0.2 * index)).astype(int)
-    up = np.rint(index + (0.2 * index)).astype(int)
-    series.forest = np.mean([series.z2n[low], series.z2n[up]])
-
-
 @jit(forceobj=True, parallel=True, fastmath=True)
 def bandwidth(series) -> None:
     """
@@ -342,14 +326,16 @@ def bandwidth(series) -> None:
     -------
     None
     """
-    forest(series)
+    if not series.potency:
+        potency(series)
+    if not series.forest:
+        forest(series)
     series.bandwidth = series.potency - series.forest
 
 
-@jit(forceobj=True, parallel=True, fastmath=True)
-def error(series) -> None:
+def forest(series) -> None:
     """
-    Calculate the uncertainty of the frequency.
+    Calculate the forest potency.
 
     Parameters
     ----------
@@ -360,11 +346,59 @@ def error(series) -> None:
     -------
     None
     """
-    bandwidth(series)
-    intersections = np.where(np.isclose(series.z2n, series.bandwidth, 0.1))
-    if intersections[0].size:
-        low = series.frequency - series.bins[intersections[0][0]]
-        up = series.bins[intersections[0][-1]] - series.frequency
-        series.error = np.mean([low, up])
+    click.secho("Select regions to estimate error.", fg='yellow')
+    regions = click.prompt("How many regions", type=int)
+    if regions > 0:
+        means = np.zeros(regions)
+        for region in range(regions):
+            flag = True
+            while flag:
+                if click.confirm(f"Is the region {region + 1} selected"):
+                    axis = plt.gca().get_xlim()
+                    lower = np.where(np.isclose(series.bins, axis[0], 0.1))
+                    upper = np.where(np.isclose(series.bins, axis[1], 0.1))
+                    low = np.rint(np.median(lower)).astype(int)
+                    up = np.rint(np.median(upper)).astype(int)
+                    means[region] = np.mean(series.z2n[low:up])
+                    flag = False
+        series.forest = np.mean(means)
     else:
-        series.error = 0
+        click.secho("No regions to estimate error.", fg='yellow')
+
+
+def gauss(series) -> None:
+    """
+    Adjust a gaussian to the natural frequency.
+
+    Parameters
+    ----------
+    series : Series
+        A time series object.
+
+    Returns
+    -------
+    None
+    """
+    def gaussian(x, amplitude, mean, sigma):
+        return amplitude * np.exp(-((x - mean) ** 2) / (2 * sigma ** 2))
+    if not series.potency:
+        potency(series)
+    bins = np.array(series.bins)
+    z2n = np.array(series.z2n)
+    mean = sum(bins * z2n) / sum(z2n)
+    sigma = np.sqrt(sum(z2n * (bins - mean) ** 2) / sum(z2n))
+    guess = [series.potency, mean, sigma]
+    popt, _ = optimize.curve_fit(gaussian, bins, z2n, guess)
+    series.frequency = np.absolute(popt[1])
+    series.error = np.absolute(popt[2])
+    period(series)
+    series.noise = np.absolute(
+        (1 / (series.frequency + series.error)) - series.period)
+    lower = series.frequency - series.error
+    upper = series.frequency + series.error
+    low = np.where(np.isclose(bins, lower, 0.1))[0][0]
+    up = np.where(np.isclose(bins, upper, 0.1))[0][-1]
+    # series.z2n[low:up] = gaussian(bins[low:up], *popt)
+    # plt.plot(bins[low:up], gaussian(bins[low:up], *popt), color='red')
+    del bins
+    del z2n
